summaryrefslogtreecommitdiff
path: root/include/ruby/impl/intern/hash.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ruby/impl/intern/hash.h')
-rw-r--r--include/ruby/impl/intern/hash.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/include/ruby/impl/intern/hash.h b/include/ruby/impl/intern/hash.h
index a0c2382410..aa82e0bbf5 100644
--- a/include/ruby/impl/intern/hash.h
+++ b/include/ruby/impl/intern/hash.h
@@ -1,5 +1,5 @@
-#ifndef RUBY3_INTERN_HASH_H /*-*-C++-*-vi:se ft=cpp:*/
-#define RUBY3_INTERN_HASH_H
+#ifndef RBIMPL_INTERN_HASH_H /*-*-C++-*-vi:se ft=cpp:*/
+#define RBIMPL_INTERN_HASH_H
/**
* @file
* @author Ruby developers <ruby-core@ruby-lang.org>
@@ -7,7 +7,7 @@
* Permission is hereby granted, to either redistribute and/or
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
* @warning Symbols prefixed with either `RUBY3` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file
* is also an implementation detail. Do not expect it to persist
@@ -24,7 +24,7 @@
#include "ruby/impl/value.h"
#include "ruby/st.h"
-RUBY3_SYMBOL_EXPORT_BEGIN()
+RBIMPL_SYMBOL_EXPORT_BEGIN()
/* hash.c */
void rb_st_foreach_safe(struct st_table *, int (*)(st_data_t, st_data_t, st_data_t), st_data_t);
@@ -54,6 +54,6 @@ VALUE rb_env_clear(void);
VALUE rb_hash_size(VALUE);
void rb_hash_free(VALUE);
-RUBY3_SYMBOL_EXPORT_END()
+RBIMPL_SYMBOL_EXPORT_END()
-#endif /* RUBY3_INTERN_HASH_H */
+#endif /* RBIMPL_INTERN_HASH_H */
@@ -7,7 +7,7 @@
* modify this file, provided that the conditions mentioned in the
* file COPYING are met. Consult the file for details.
- * @warning Symbols prefixed with either `RUBY3` or `ruby3` are
+ * @warning Symbols prefixed with either `RBIMPL` or `ruby3` are
* implementation details. Don't take them as canon. They could
* rapidly appear then vanish. The name (path) of this header file